@@ -1,5 +1,6 @@
 """Data models used in EuroEval."""
 
+import collections.abc as c
 import json
 import pathlib
 import re
@@ -10,79 +11,42 @@ import pydantic
 import torch
 
 from .enums import Device, GenerativeType, ModelType, TaskGroup
+from .exceptions import InvalidBenchmark
+from .languages import ENGLISH, NORWEGIAN, PORTUGUESE, Language
+from .metrics.base import Metric
 from .types import ScoreDict
 from .utils import get_package_version
 
 if t.TYPE_CHECKING:
     from .enums import InferenceBackend
-    from .metrics import Metric
 
 
 @dataclass
-class Language:
-    """A benchmarkable language.
+class PromptConfig:
+    """Configuration for task-specific prompting across languages.
+
+    Defines the prompt templates needed for evaluating a specific task in a given
+    language.
 
     Attributes:
-        code:
-            The ISO 639-1 language code of the language.
-        name:
-            The name of the language.
-        and_separator (optional):
-            The word 'and' in the language.
-        or_separator (optional):
-            The word 'or' in the language.
+        default_prompt_prefix:
+            The default prefix to use in the few-shot prompt.
+        default_prompt_template:
+            The default template for the prompt to use when benchmarking the dataset
+            using few-shot evaluation.
+        default_instruction_prompt:
+            The default prompt to use when benchmarking the dataset using
+            instruction-based evaluation.
+        default_prompt_label_mapping:
+            The default mapping from the labels to another phrase which is used as a
+            substitute for the label in few-shot evaluation. If set to "auto", the
+            mapping will be set to a 1:1 mapping between the labels and themselves.
     """
 
-    code: str
-    name: str
-    _and_separator: str | None = field(repr=False, default=None)
-    _or_separator: str | None = field(repr=False, default=None)
-
-    def __hash__(self) -> int:
-        """Return a hash of the language."""
-        return hash(self.code)
-
-    @property
-    def and_separator(self) -> str:
-        """Get the word 'and' in the language.
-
-        Returns:
-            The word 'and' in the language.
-
-        Raises:
-            NotImplementedError:
-                If `and_separator` is `None`.
-        """
-        if not self._and_separator:
-            raise NotImplementedError(
-                f"Separator for the word 'and' has not been defined for {self.name}."
-            )
-        return self._and_separator
-
-    @and_separator.setter
-    def and_separator(self, value: str | None) -> None:
-        self._and_separator = value
-
-    @property
-    def or_separator(self) -> str:
-        """Get the word 'or' in the language.
-
-        Returns:
-            The word 'or' in the language.
-
-        Raises:
-            NotImplementedError:
-                If `or_separator` is `None`.
-        """
-        if not self._or_separator:
-            raise NotImplementedError(
-                f"Separator for the word 'or' has not been defined for {self.name}."
-            )
-        return self._or_separator
-
-    @or_separator.setter
-    def or_separator(self, value: str | None) -> None:
-        self._or_separator = value
+    default_prompt_prefix: str
+    default_prompt_template: str
+    default_instruction_prompt: str
+    default_prompt_label_mapping: dict[str, str] | t.Literal["auto"]
 
 
 @dataclass
@@ -133,21 +97,25 @@ class Task:
             considered incorrect and the evaluation will be aborted. Defaults to True.
     """
 
+    model_config = pydantic.ConfigDict(
+        protected_namespaces=(), arbitrary_types_allowed=True
+    )
+
     name: str
     task_group: TaskGroup
-    template_dict: dict["Language", "PromptConfig"]
-    metrics: list["Metric"]
+    template_dict: dict[Language, PromptConfig]
+    metrics: c.Sequence[Metric]
     default_num_few_shot_examples: int
     default_max_generated_tokens: int
-    default_labels: list[str]
+    default_labels: c.Sequence[str] | None
     requires_zero_shot: bool = False
     uses_structured_output: bool = False
     uses_logprobs: bool = False
     requires_logprobs: bool = False
-    default_allowed_model_types: list[ModelType] = field(
+    default_allowed_model_types: c.Sequence[ModelType] = field(
         default_factory=lambda: [ModelType.ENCODER, ModelType.GENERATIVE]
     )
-    default_allowed_generative_types: list[GenerativeType] = field(
+    default_allowed_generative_types: c.Sequence[GenerativeType] = field(
         default_factory=lambda: [
             GenerativeType.BASE,
             GenerativeType.INSTRUCTION_TUNED,
@@ -165,21 +133,328 @@ class Task:
         return hash(self.name)
 
 
+@dataclass
+class DatasetConfig:
+    """Configuration for a dataset.
+
+    Attributes:
+        name:
+            The name of the dataset. Must be lower case with no spaces.
+        pretty_name:
+            A longer prettier name for the dataset, which allows cases and spaces. Used
+            for logging.
+        source:
+            The source of the dataset, which can be a Hugging Face ID or a dictionary
+            with keys "train", "val" and "test" mapping to local CSV file paths.
+        task:
+            The task of the dataset.
+        languages:
+            The ISO 639-1 language codes of the entries in the dataset.
+        id2label:
+            The mapping from ID to label.
+        label2id:
+            The mapping from label to ID.
+        num_labels:
+            The number of labels in the dataset.
+        _prompt_prefix (optional):
+            The prefix to use in the few-shot prompt. Defaults to the template for the
+            task and language.
+        _prompt_template (optional):
+            The template for the prompt to use when benchmarking the dataset using
+            few-shot evaluation. Defaults to the template for the task and language.
+        _instruction_prompt (optional):
+            The prompt to use when benchmarking the dataset using instruction-based
+            evaluation. Defaults to the template for the task and language.
+        _num_few_shot_examples (optional):
+            The number of examples to use when benchmarking the dataset using few-shot
+            evaluation. For a classification task, these will be drawn evenly from
+            each label. Defaults to the template for the task and language.
+        _max_generated_tokens (optional):
+            The maximum number of tokens to generate when benchmarking the dataset
+            using few-shot evaluation. Defaults to the template for the task and
+            language.
+        _labels (optional):
+            The labels in the dataset. Defaults to the template for the task and
+            language.
+        _prompt_label_mapping (optional):
+            A mapping from the labels to another phrase which is used as a substitute
+            for the label in few-shot evaluation. If "auto" then the mapping will be set
+            to a 1:1 mapping between the labels and themselves. If None then the mapping
+            will be set to the default mapping for the task and language. Defaults to
+            None.
+        _allowed_model_types (optional):
+            A list of model types that are allowed to be evaluated on this dataset.
+            Defaults to the one for the task.
+        _allowed_generative_types (optional):
+            A list of generative model types that are allowed to be evaluated on this
+            dataset. If None, all generative model types are allowed. Only relevant if
+            `allowed_model_types` includes generative models. Defaults to the one for
+            the task.
+        _allow_invalid_model_outputs (optional):
+            Whether to allow invalid model outputs. This is only relevant for
+            generative models on classification tasks, where the model may generate an
+            output which is not one of the allowed labels. If True, the model output
+            will be mapped to the closest valid label. If False, the model output will
+            be considered incorrect and the evaluation will be aborted. Defaults to
+            the one for the task.
+        _logging_string (optional):
+            The string used to describe evaluation on the dataset in logging. If not
+            provided, a default string will be generated, based on the pretty name. Only
+            use this if the default string is not suitable.
+        splits (optional):
+            The names of the splits in the dataset. If not provided, defaults to
+            ["train", "val", "test"].
+        bootstrap_samples (optional):
+            Whether to bootstrap the dataset samples. Defaults to True.
+        unofficial (optional):
+            Whether the dataset is unofficial. Defaults to False.
+    """
+
+    name: str
+    pretty_name: str
+    source: str | dict[str, str]
+    task: Task
+    languages: c.Sequence[Language]
+    _prompt_prefix: str | None = None
+    _prompt_template: str | None = None
+    _instruction_prompt: str | None = None
+    _num_few_shot_examples: int | None = None
+    _max_generated_tokens: int | None = None
+    _labels: c.Sequence[str] | None = None
+    _prompt_label_mapping: dict[str, str] | t.Literal["auto"] | None = None
+    _allowed_model_types: c.Sequence[ModelType] | None = None
+    _allowed_generative_types: c.Sequence[GenerativeType] | None = None
+    _allow_invalid_model_outputs: bool | None = None
+    _logging_string: str | None = None
+    splits: c.Sequence[str] = field(default_factory=lambda: ["train", "val", "test"])
+    bootstrap_samples: bool = True
+    unofficial: bool = False
+
+    @property
+    def main_language(self) -> Language:
+        """Get the main language of the dataset.
+
+        Returns:
+            The main language.
+        """
+        match len(self.languages):
+            case 0:
+                raise InvalidBenchmark(
+                    f"Dataset {self.name!r} must have at least one language."
+                )
+            case 1:
+                return self.languages[0]
+            case _:
+                if ENGLISH in self.languages:
+                    return ENGLISH
+                elif NORWEGIAN in self.languages:
+                    return NORWEGIAN
+                elif PORTUGUESE in self.languages:
+                    return PORTUGUESE
+                else:
+                    return self.languages[0]
+
+    @property
+    def logging_string(self) -> str:
+        """The string used to describe evaluation on the dataset in logging."""
+        if self._logging_string is not None:
+            return self._logging_string
+        truncated_str = (
+            "truncated version of the "
+            if isinstance(self.source, str) and self.source.endswith("-mini")
+            else ""
+        )
+        if len(self.languages) > 1:
+            languages_str = (
+                ", ".join([lang.name for lang in self.languages[:-1]])
+                + f" and {self.languages[-1].name}"
+            )
+        else:
+            languages_str = self.languages[0].name
+        task_str = self.task.name.replace("-", " ")
+        dataset_name_str = (
+            self.pretty_name or self.name.replace("-", " ").replace("_", " ").title()
+        )
+        return (
+            f"the {truncated_str}{languages_str} {task_str} dataset {dataset_name_str}"
+        )
+
+    @property
+    def prompt_prefix(self) -> str:
+        """The prefix to use in the few-shot prompt."""
+        prompt_config = self.task.template_dict[self.main_language]
+        prompt_prefix = (
+            prompt_config.default_prompt_prefix
+            if self._prompt_prefix is None
+            else self._prompt_prefix
+        )
+        return prompt_prefix
+
+    @property
+    def prompt_template(self) -> str:
+        """The template used during few-shot evaluation."""
+        prompt_config = self.task.template_dict[self.main_language]
+        prompt_template = (
+            prompt_config.default_prompt_template
+            if self._prompt_template is None
+            else self._prompt_template
+        )
+        return prompt_template
+
+    @property
+    def instruction_prompt(self) -> str:
+        """The prompt to use when evaluating instruction-tuned models."""
+        prompt_config = self.task.template_dict[self.main_language]
+        instruction_prompt = (
+            prompt_config.default_instruction_prompt
+            if self._instruction_prompt is None
+            else self._instruction_prompt
+        )
+        return instruction_prompt
+
+    @property
+    def num_few_shot_examples(self) -> int:
+        """The number of few-shot examples to use."""
+        return (
+            self._num_few_shot_examples
+            if self._num_few_shot_examples is not None
+            else self.task.default_num_few_shot_examples
+        )
+
+    @property
+    def max_generated_tokens(self) -> int:
+        """The maximum number of tokens to generate when evaluating a model."""
+        return (
+            self._max_generated_tokens
+            if self._max_generated_tokens is not None
+            else self.task.default_max_generated_tokens
+        )
+
+    @property
+    def labels(self) -> c.Sequence[str]:
+        """The labels in the dataset."""
+        if self._labels is not None:
+            return self._labels
+        elif self.task.default_labels is not None:
+            return self.task.default_labels
+        else:
+            raise ValueError(
+                f"Labels must be specified for dataset {self.name!r} with the "
+                f"attribute `_labels`, as the task {self.task.name!r} does not have "
+                "default labels."
+            )
+
+    @property
+    def prompt_label_mapping(self) -> dict[str, str]:
+        """Mapping from English labels to localised labels."""
+        if self._prompt_label_mapping == "auto":
+            return {label: label for label in self.labels}
+        elif self._prompt_label_mapping is not None:
+            return self._prompt_label_mapping
+        prompt_config = self.task.template_dict[self.main_language]
+        if prompt_config.default_prompt_label_mapping == "auto":
+            return {label: label for label in self.labels}
+        else:
+            return prompt_config.default_prompt_label_mapping
+
+    @property
+    def allowed_model_types(self) -> c.Sequence[ModelType]:
+        """A list of model types that are allowed to be evaluated on this dataset."""
+        return (
+            self._allowed_model_types
+            if self._allowed_model_types is not None
+            else self.task.default_allowed_model_types
+        )
+
+    @property
+    def allowed_generative_types(self) -> c.Sequence[GenerativeType]:
+        """A list of generative model types that are allowed on this dataset."""
+        return (
+            self._allowed_generative_types
+            if self._allowed_generative_types is not None
+            else self.task.default_allowed_generative_types
+        )
+
+    @property
+    def allow_invalid_model_outputs(self) -> bool:
+        """Whether to allow invalid model outputs."""
+        return (
+            self._allow_invalid_model_outputs
+            if self._allow_invalid_model_outputs is not None
+            else self.task.default_allow_invalid_model_outputs
+        )
+
+    @property
+    def id2label(self) -> "HashableDict":
+        """The mapping from ID to label."""
+        return HashableDict({idx: label for idx, label in enumerate(self.labels)})
+
+    @property
+    def label2id(self) -> "HashableDict":
+        """The mapping from label to ID."""
+        return HashableDict({label: i for i, label in enumerate(self.labels)})
+
+    @property
+    def num_labels(self) -> int:
+        """The number of labels in the dataset."""
+        return len(self.labels)
+
+    def __hash__(self) -> int:
+        """Return a hash of the dataset configuration."""
+        return hash(self.name)
+
+    def get_labels_str(self, labels: c.Sequence[str] | None = None) -> str:
+        """Converts a set of labels to a natural string, in the specified language.
+
+        If the task is NER, we separate using 'and' and use the mapped labels instead of
+        the BIO NER labels.
+
+        Args:
+            labels (optional):
+                The labels to convert to a natural string. If None, uses all the labels
+                in the dataset. Defaults to None.
+
+        Returns:
+            The natural string representation of the labels in specified language.
+        """
+        if self.task.task_group == TaskGroup.TOKEN_CLASSIFICATION:
+            sep_word = self.main_language.and_separator
+        else:
+            sep_word = self.main_language.or_separator
+
+        if labels is None:
+            labels = list()
+            for english_label in self.labels:
+                if english_label not in self.prompt_label_mapping:
+                    continue
+                label = self.prompt_label_mapping[english_label]
+                if label not in labels:
+                    labels.append(label)
+
+        # Convert labels to single-quoted labels - and remove duplicates
+        quoted_labels = [f"'{label}'" for label in labels]
+
+        if not quoted_labels:
+            return ""
+        elif len(quoted_labels) == 1:
+            return quoted_labels[0]
+        elif len(quoted_labels) == 2:
+            return f"{quoted_labels[0]} {sep_word} {quoted_labels[1]}"
+        else:
+            return f"{', '.join(quoted_labels[:-1])} {sep_word} {quoted_labels[-1]}"
+
+
 @dataclass
 class BenchmarkConfig:
     """General benchmarking configuration, across datasets and models.
 
     Attributes:
-        tasks:
-            The tasks benchmark the model(s) on.
         datasets:
             The datasets to benchmark on.
         model_languages:
             The languages of the models to benchmark.
         dataset_languages:
             The languages of the datasets in the benchmark.
-        device:
-            The device to use for benchmarking.
         batch_size:
             The batch size to use.
         raise_errors:
@@ -198,6 +473,8 @@ class BenchmarkConfig:
             Whether to show a progress bar.
         save_results:
             Whether to save the benchmark results to 'euroeval_benchmark_results.json'.
+        device:
+            The device to use for benchmarking.
         trust_remote_code:
             Whether to trust remote code when loading models from the Hugging Face Hub.
         clear_model_cache:
@@ -233,10 +510,9 @@ class BenchmarkConfig:
             Whether the benchmark is being run with the CLI.
     """
 
-    model_languages: list[Language]
-    dataset_languages: list[Language]
-    tasks: list[Task]
-    datasets: list[str]
+    datasets: c.Sequence[DatasetConfig]
+    model_languages: c.Sequence[Language]
+    dataset_languages: c.Sequence[Language]
     batch_size: int
     raise_errors: bool
     cache_dir: str
@@ -260,19 +536,26 @@ class BenchmarkConfig:
     debug: bool
     run_with_cli: bool
 
+    @property
+    def tasks(self) -> c.Sequence[Task]:
+        """Get the tasks in the benchmark configuration."""
+        return list({dataset_config.task for dataset_config in self.datasets})
+
 
 class BenchmarkConfigParams(pydantic.BaseModel):
     """The parameters for the benchmark configuration."""
 
-    model_config = pydantic.ConfigDict(protected_namespaces=())
+    model_config = pydantic.ConfigDict(
+        protected_namespaces=(), arbitrary_types_allowed=True
+    )
 
-    task: str | list[str] | None
-    dataset: str | list[str] | None
+    task: str | Task | c.Sequence[str | Task] | None
+    dataset: str | DatasetConfig | c.Sequence[str | DatasetConfig] | None
     progress_bar: bool
     save_results: bool
-    language: str | list[str]
-    model_language: str | list[str] | None
-    dataset_language: str | list[str] | None
+    language: str | c.Sequence[str]
+    model_language: str | c.Sequence[str] | None
+    dataset_language: str | c.Sequence[str] | None
     device: Device | None
     batch_size: int
     raise_errors: bool
@@ -300,7 +583,7 @@ class BenchmarkResult(pydantic.BaseModel):
 
     dataset: str
     task: str
-    dataset_languages: list[str]
+    dataset_languages: c.Sequence[str]
     model: str
     results: ScoreDict
     num_model_parameters: int
@@ -364,261 +647,6 @@ class BenchmarkResult(pydantic.BaseModel):
             f.write("\n" + json_str)
 
 
-@dataclass
-class DatasetConfig:
-    """Configuration for a dataset.
-
-    Attributes:
-        name:
-            The name of the dataset. Must be lower case with no spaces.
-        pretty_name:
-            A longer prettier name for the dataset, which allows cases and spaces. Used
-            for logging.
-        huggingface_id:
-            The Hugging Face ID of the dataset.
-        task:
-            The task of the dataset.
-        languages:
-            The ISO 639-1 language codes of the entries in the dataset.
-        id2label:
-            The mapping from ID to label.
-        label2id:
-            The mapping from label to ID.
-        num_labels:
-            The number of labels in the dataset.
-        _prompt_prefix (optional):
-            The prefix to use in the few-shot prompt. Defaults to the template for the
-            task and language.
-        _prompt_template (optional):
-            The template for the prompt to use when benchmarking the dataset using
-            few-shot evaluation. Defaults to the template for the task and language.
-        _instruction_prompt (optional):
-            The prompt to use when benchmarking the dataset using instruction-based
-            evaluation. Defaults to the template for the task and language.
-        _num_few_shot_examples (optional):
-            The number of examples to use when benchmarking the dataset using few-shot
-            evaluation. For a classification task, these will be drawn evenly from
-            each label. Defaults to the template for the task and language.
-        _max_generated_tokens (optional):
-            The maximum number of tokens to generate when benchmarking the dataset
-            using few-shot evaluation. Defaults to the template for the task and
-            language.
-        _labels (optional):
-            The labels in the dataset. Defaults to the template for the task and
-            language.
-        _prompt_label_mapping (optional):
-            A mapping from the labels to another phrase which is used as a substitute
-            for the label in few-shot evaluation. If "auto" then the mapping will be set
-            to a 1:1 mapping between the labels and themselves. If None then the mapping
-            will be set to the default mapping for the task and language. Defaults to
-            None.
-        _allowed_model_types (optional):
-            A list of model types that are allowed to be evaluated on this dataset.
-            Defaults to the one for the task.
-        _allowed_generative_types (optional):
-            A list of generative model types that are allowed to be evaluated on this
-            dataset. If None, all generative model types are allowed. Only relevant if
-            `allowed_model_types` includes generative models. Defaults to the one for
-            the task.
-        _allow_invalid_model_outputs (optional):
-            Whether to allow invalid model outputs. This is only relevant for
-            generative models on classification tasks, where the model may generate an
-            output which is not one of the allowed labels. If True, the model output
-            will be mapped to the closest valid label. If False, the model output will
-            be considered incorrect and the evaluation will be aborted. Defaults to
-            the one for the task.
-        splits (optional):
-            The names of the splits in the dataset. If not provided, defaults to
-            ["train", "val", "test"].
-        bootstrap_samples (optional):
-            Whether to bootstrap the dataset samples. Defaults to True.
-        unofficial (optional):
-            Whether the dataset is unofficial. Defaults to False.
-    """
-
-    name: str
-    pretty_name: str
-    huggingface_id: str
-    task: Task
-    languages: list[Language]
-    _prompt_prefix: str | None = None
-    _prompt_template: str | None = None
-    _instruction_prompt: str | None = None
-    _num_few_shot_examples: int | None = None
-    _max_generated_tokens: int | None = None
-    _labels: list[str] | None = None
-    _prompt_label_mapping: dict[str, str] | t.Literal["auto"] | None = None
-    _allowed_model_types: list[ModelType] | None = None
-    _allowed_generative_types: list[GenerativeType] | None = None
-    _allow_invalid_model_outputs: bool | None = None
-    splits: list[str] = field(default_factory=lambda: ["train", "val", "test"])
-    bootstrap_samples: bool = True
-    unofficial: bool = False
-
-    @property
-    def prompt_prefix(self) -> str:
-        """The prefix to use in the few-shot prompt."""
-        main_language = self.languages[0]
-        prompt_config = self.task.template_dict[main_language]
-        prompt_prefix = (
-            prompt_config.default_prompt_prefix
-            if self._prompt_prefix is None
-            else self._prompt_prefix
-        )
-        return prompt_prefix
-
-    @property
-    def prompt_template(self) -> str:
-        """The template used during few-shot evaluation."""
-        main_language = self.languages[0]
-        prompt_config = self.task.template_dict[main_language]
-        prompt_template = (
-            prompt_config.default_prompt_template
-            if self._prompt_template is None
-            else self._prompt_template
-        )
-        return prompt_template
-
-    @property
-    def instruction_prompt(self) -> str:
-        """The prompt to use when evaluating instruction-tuned models."""
-        main_language = self.languages[0]
-        prompt_config = self.task.template_dict[main_language]
-        instruction_prompt = (
-            prompt_config.default_instruction_prompt
-            if self._instruction_prompt is None
-            else self._instruction_prompt
-        )
-        return instruction_prompt
-
-    @property
-    def num_few_shot_examples(self) -> int:
-        """The number of few-shot examples to use."""
-        return (
-            self._num_few_shot_examples
-            if self._num_few_shot_examples is not None
-            else self.task.default_num_few_shot_examples
-        )
-
-    @property
-    def max_generated_tokens(self) -> int:
-        """The maximum number of tokens to generate when evaluating a model."""
-        return (
-            self._max_generated_tokens
-            if self._max_generated_tokens is not None
-            else self.task.default_max_generated_tokens
-        )
-
-    @property
-    def labels(self) -> list[str]:
-        """The labels in the dataset."""
-        return self._labels if self._labels is not None else self.task.default_labels
-
-    @property
-    def prompt_label_mapping(self) -> dict[str, str]:
-        """Mapping from English labels to localised labels."""
-        if self._prompt_label_mapping == "auto":
-            return {label: label for label in self.labels}
-        elif self._prompt_label_mapping is not None:
-            return self._prompt_label_mapping
-
-        main_language = self.languages[0]
-        prompt_config = self.task.template_dict[main_language]
-
-        if prompt_config.default_prompt_label_mapping == "auto":
-            return {label: label for label in self.labels}
-        else:
-            return prompt_config.default_prompt_label_mapping
-
-    @property
-    def allowed_model_types(self) -> list[ModelType]:
-        """A list of model types that are allowed to be evaluated on this dataset."""
-        return (
-            self._allowed_model_types
-            if self._allowed_model_types is not None
-            else self.task.default_allowed_model_types
-        )
-
-    @property
-    def allowed_generative_types(self) -> list[GenerativeType]:
-        """A list of generative model types that are allowed on this dataset."""
-        return (
-            self._allowed_generative_types
-            if self._allowed_generative_types is not None
-            else self.task.default_allowed_generative_types
-        )
-
-    @property
-    def allow_invalid_model_outputs(self) -> bool:
-        """Whether to allow invalid model outputs."""
-        return (
-            self._allow_invalid_model_outputs
-            if self._allow_invalid_model_outputs is not None
-            else self.task.default_allow_invalid_model_outputs
-        )
-
-    @property
-    def id2label(self) -> "HashableDict":
-        """The mapping from ID to label."""
-        return HashableDict({idx: label for idx, label in enumerate(self.labels)})
-
-    @property
-    def label2id(self) -> "HashableDict":
-        """The mapping from label to ID."""
-        return HashableDict({label: i for i, label in enumerate(self.labels)})
-
-    @property
-    def num_labels(self) -> int:
-        """The number of labels in the dataset."""
-        return len(self.labels)
-
-    def __hash__(self) -> int:
-        """Return a hash of the dataset configuration."""
-        return hash(self.name)
-
-    def get_labels_str(self, labels: list[str] | None = None) -> str:
-        """Converts a set of labels to a natural string, in the specified language.
-
-        If the task is NER, we separate using 'and' and use the mapped labels instead of
-        the BIO NER labels.
-
-        Args:
-            labels (optional):
-                The labels to convert to a natural string. If None, uses all the labels
-                in the dataset. Defaults to None.
-
-        Returns:
-            The natural string representation of the labels in specified language.
-        """
-        main_language = self.languages[0]
-
-        if self.task.task_group == TaskGroup.TOKEN_CLASSIFICATION:
-            sep_word = main_language.and_separator
-        else:
-            sep_word = main_language.or_separator
-
-        if labels is None:
-            labels = list()
-            for english_label in self.labels:
-                if english_label not in self.prompt_label_mapping:
-                    continue
-                label = self.prompt_label_mapping[english_label]
-                if label not in labels:
-                    labels.append(label)
-
-        # Convert labels to single-quoted labels - and remove duplicates
-        quoted_labels = [f"'{label}'" for label in labels]
-
-        if not quoted_labels:
-            return ""
-        elif len(quoted_labels) == 1:
-            return quoted_labels[0]
-        elif len(quoted_labels) == 2:
-            return f"{quoted_labels[0]} {sep_word} {quoted_labels[1]}"
-        else:
-            return f"{', '.join(quoted_labels[:-1])} {sep_word} {quoted_labels[-1]}"
-
-
 @dataclass
 class ModelConfig:
     """Configuration for a model.
@@ -653,7 +681,7 @@ class ModelConfig:
     revision: str
     param: str | None
     task: str
-    languages: list[Language]
+    languages: c.Sequence[Language]
     inference_backend: "InferenceBackend"
     merge: bool
     model_type: ModelType
@@ -681,7 +709,7 @@ class PreparedModelInputs:
             instead.
     """
 
-    texts: list[str] | None = None
+    texts: c.Sequence[str] | None = None
     input_ids: torch.Tensor | None = None
     attention_mask: torch.Tensor | None = None
 
@@ -699,8 +727,8 @@ class GenerativeModelOutput:
             token and its logprob. Can be None if the scores are not available.
     """
 
-    sequences: list[str]
-    scores: list[list[list[tuple[str, float]]]] | None = None
+    sequences: c.Sequence[str]
+    scores: c.Sequence[c.Sequence[c.Sequence[tuple[str, float]]]] | None = None
 
 
 @dataclass
@@ -717,7 +745,7 @@ class SingleGenerativeModelOutput:
     """
 
     sequence: str
-    scores: list[list[tuple[str, float]]] | None = None
+    scores: c.Sequence[c.Sequence[tuple[str, float]]] | None = None
 
 
 @dataclass
@@ -735,38 +763,10 @@ class HFModelInfo:
     """
 
     pipeline_tag: str
-    tags: list[str]
+    tags: c.Sequence[str]
     adapter_base_model_id: str | None
 
 
-@dataclass
-class PromptConfig:
-    """Configuration for task-specific prompting across languages.
-
-    Defines the prompt templates needed for evaluating a specific task in a given
-    language.
-
-    Attributes:
-        default_prompt_prefix:
-            The default prefix to use in the few-shot prompt.
-        default_prompt_template:
-            The default template for the prompt to use when benchmarking the dataset
-            using few-shot evaluation.
-        default_instruction_prompt:
-            The default prompt to use when benchmarking the dataset using
-            instruction-based evaluation.
-        default_prompt_label_mapping:
-            The default mapping from the labels to another phrase which is used as a
-            substitute for the label in few-shot evaluation. If set to "auto", the
-            mapping will be set to a 1:1 mapping between the labels and themselves.
-    """
-
-    default_prompt_prefix: str
-    default_prompt_template: str
-    default_instruction_prompt: str
-    default_prompt_label_mapping: dict[str, str] | t.Literal["auto"]
-
-
 @dataclass
 class ModelIdComponents:
     """A model ID split into its components.
