@@ -5,14 +5,12 @@ import typing as t
 
 from . import benchmark_modules
 from .exceptions import InvalidModel, NeedsEnvironmentVariable, NeedsExtraInstalled
+from .logging_utils import log
 
 if t.TYPE_CHECKING:
     from .data_models import BenchmarkConfig, ModelConfig
 
 
-logger = logging.getLogger("euroeval")
-
-
 def get_model_config(
     model_id: str, benchmark_config: "BenchmarkConfig"
 ) -> "ModelConfig":
@@ -51,9 +49,10 @@ def get_model_config(
         elif isinstance(exists_or_err, NeedsEnvironmentVariable):
             needs_env_vars.append(exists_or_err.env_var)
         elif exists_or_err is True:
-            logger.debug(
+            log(
                 f"The model {model_id!r} was identified by the "
-                f"{benchmark_module.__name__} benchmark module."
+                f"{benchmark_module.__name__} benchmark module.",
+                logging.DEBUG,
             )
             model_config = benchmark_module.get_model_config(
                 model_id=model_id, benchmark_config=benchmark_config
