@@ -35,7 +35,7 @@ def load_model(
     Returns:
         The model.
     """
-    log_once(f"Loading the model {model_config.model_id}...")
+    log_once(f"\nLoading the model {model_config.model_id}...")
 
     # The order matters; the first model type that matches will be used. For this
     # reason, they have been ordered in terms of the most common model types.
