@@ -4,48 +4,59 @@ import typing as t
 
 from ..data_models import PromptConfig
 from ..languages import (
-    CS,
-    DA,
-    DE,
-    EN,
-    ES,
-    ET,
-    FI,
-    FO,
-    FR,
-    IS,
-    IT,
-    LT,
-    LV,
-    NB,
-    NL,
-    NN,
-    NO,
-    PL,
-    PT,
-    SK,
-    SV,
+    BULGARIAN,
+    CZECH,
+    DANISH,
+    DUTCH,
+    ENGLISH,
+    ESTONIAN,
+    FAROESE,
+    FINNISH,
+    FRENCH,
+    GERMAN,
+    GREEK,
+    ICELANDIC,
+    ITALIAN,
+    LATVIAN,
+    LITHUANIAN,
+    NORWEGIAN,
+    NORWEGIAN_BOKMÅL,
+    NORWEGIAN_NYNORSK,
+    POLISH,
+    PORTUGUESE,
+    SERBIAN,
+    SLOVAK,
+    SPANISH,
+    SWEDISH,
+    UKRAINIAN,
 )
 
 if t.TYPE_CHECKING:
-    from ..data_models import Language
+    from ..languages import Language
 
 LA_TEMPLATES: dict["Language", PromptConfig] = {
-    CS: PromptConfig(
+    BULGARIAN: PromptConfig(
+        default_prompt_label_mapping=dict(correct="да", incorrect="не"),
+        default_prompt_prefix="Следват изречения и дали са граматически правилни.",
+        default_prompt_template="Изречение: {text}\nГраматически правилно: {label}",
+        default_instruction_prompt="Изречение: {text}\n\nОпределете дали изречението е "
+        "граматически правилно или не. Отговорете с {labels_str}, и нищо друго.",
+    ),
+    CZECH: PromptConfig(
         default_prompt_label_mapping=dict(correct="ano", incorrect="ne"),
         default_prompt_prefix="Následující jsou věty a zda jsou gramaticky správné.",
         default_prompt_template="Věta: {text}\nGramaticky správná: {label}",
         default_instruction_prompt="Věta: {text}\n\nUrčete, zda je věta gramaticky "
         "správná nebo ne. Odpovězte {labels_str}, a nic jiné.",
     ),
-    DA: PromptConfig(
+    DANISH: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nej"),
         default_prompt_prefix="Følgende er sætninger og om de er grammatisk korrekte.",
         default_prompt_template="Sætning: {text}\nGrammatisk korrekt: {label}",
         default_instruction_prompt="Sætning: {text}\n\nBestem om sætningen er "
         "grammatisk korrekt eller ej. Svar kun med {labels_str}, og intet andet.",
     ),
-    DE: PromptConfig(
+    GERMAN: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nein"),
         default_prompt_prefix="Die folgenden Sätze und ob sie grammatikalisch korrekt "
         "sind.",
@@ -54,7 +65,15 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         "grammatikalisch korrekt ist oder nicht. Antworten Sie mit {labels_str}, und "
         "nichts anderes.",
     ),
-    EN: PromptConfig(
+    GREEK: PromptConfig(
+        default_prompt_label_mapping=dict(correct="ναι", incorrect="όχι"),
+        default_prompt_prefix="Οι ακόλουθες είναι προτάσεις και εάν είναι "
+        "γραμματικά σωστές.",
+        default_prompt_template="Πρόταση: {text}\nΓραμματικά σωστή: {label}",
+        default_instruction_prompt="Πρόταση: {text}\n\nΠροσδιορίστε εάν η πρόταση "
+        "είναι γραμματικά σωστή ή όχι. Απαντήστε με {labels_str}, και τίποτα άλλο.",
+    ),
+    ENGLISH: PromptConfig(
         default_prompt_label_mapping=dict(correct="yes", incorrect="no"),
         default_prompt_prefix="The following are sentences and whether they are "
         "grammatically correct.",
@@ -62,7 +81,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Sentence: {text}\n\nDetermine whether the sentence "
         "is grammatically correct or not. Answer with {labels_str}, and nothing else.",
     ),
-    ES: PromptConfig(
+    SPANISH: PromptConfig(
         default_prompt_label_mapping=dict(correct="sí", incorrect="no"),
         default_prompt_prefix="Lo siguiente son textos y si son gramaticalmente "
         "correctos.",
@@ -70,7 +89,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Texto: {text}\n\nDetermina si el texto es "
         "gramaticalmente correcto o no. Responde con {labels_str}, y nada más.",
     ),
-    ET: PromptConfig(
+    ESTONIAN: PromptConfig(
         default_prompt_label_mapping=dict(correct="jah", incorrect="ei"),
         default_prompt_prefix="Järgnevad on laused ja kas need on grammatiliselt "
         "õiged.",
@@ -78,7 +97,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Lause: {text}\n\nOtsusta, kas lause on "
         "grammatiliselt õige või mitte. Vasta {labels_str}, ja mitte midagi muud.",
     ),
-    PL: PromptConfig(
+    POLISH: PromptConfig(
         default_prompt_label_mapping=dict(correct="tak", incorrect="nie"),
         default_prompt_prefix="Poniżej znajdują się teksty i informacja, czy są "
         "gramatycznie poprawne.",
@@ -86,7 +105,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Tekst: {text}\n\nOkreśl, czy tekst jest "
         "gramatycznie poprawny. Odpowiedz używając wyłącznie {labels_str}.",
     ),
-    PT: PromptConfig(
+    PORTUGUESE: PromptConfig(
         default_prompt_label_mapping=dict(correct="sim", incorrect="não"),
         default_prompt_prefix="Seguem-se abaixo textos e se são "
         "gramaticalmente correctos",
@@ -94,7 +113,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Texto: {text}\n\nDetermina se o texto é "
         "gramaticalmente correcto ou não. Responde com {labels_str}, e nada mais.",
     ),
-    FI: PromptConfig(
+    FINNISH: PromptConfig(
         default_prompt_label_mapping=dict(correct="kyllä", incorrect="ei"),
         default_prompt_prefix="Seuraavat ovat lauseita ja ovatko ne "
         "kieliopillisesti oikein.",
@@ -102,7 +121,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Lause: {text}\n\nMääritä onko lause "
         "oikein vai ei. Vastaa {labels_str}, ja ei mitään muuta.",
     ),
-    FO: PromptConfig(
+    FAROESE: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nei"),
         default_prompt_prefix="Hetta eru nakrir setningar og um teir eru mállæruliga "
         "rættir.",
@@ -110,7 +129,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Setningur: {text}\n\nGreindu hvort setningurin er "
         "mállæruliga rættur ella ikki. Svara við {labels_str}, og einki annað.",
     ),
-    FR: PromptConfig(
+    FRENCH: PromptConfig(
         default_prompt_label_mapping=dict(correct="oui", incorrect="non"),
         default_prompt_prefix="Les phrases suivantes indiquent si elles sont "
         "grammaticalement correctes.",
@@ -119,7 +138,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Phrase: {text}\n\nDéterminez si la phrase est "
         "grammaticalement correcte ou non. Répondez par {labels_str}, et rien d'autre.",
     ),
-    IS: PromptConfig(
+    ICELANDIC: PromptConfig(
         default_prompt_label_mapping=dict(correct="já", incorrect="nei"),
         default_prompt_prefix="Hér fyrir neðan eru setningar ásamt mati á því hvort "
         "þær eru málfræðilega réttar.",
@@ -128,7 +147,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         "málfræðilega rétt. Svaraðu með 'já' ef setningin er rétt og 'nei' ef hún "
         "er það ekki.",
     ),
-    IT: PromptConfig(
+    ITALIAN: PromptConfig(
         default_prompt_label_mapping=dict(correct="si", incorrect="no"),
         default_prompt_prefix="Di seguito sono riportate le frasi e la loro "
         "correttezza grammaticale.",
@@ -136,7 +155,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Frase: {text}\n\nStabilite se la frase è "
         "grammaticalmente corretta o meno. Rispondere con {labels_str}, e nient'altro.",
     ),
-    LT: PromptConfig(
+    LITHUANIAN: PromptConfig(
         default_prompt_label_mapping=dict(correct="taip", incorrect="ne"),
         default_prompt_prefix="Toliau pateikti sakiniai ir ar jie yra gramatiškai "
         "teisingi.",
@@ -144,14 +163,14 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Sakinys: {text}\n\nNustatykite, ar sakinys yra "
         "gramatiškai teisingas, ar ne. Atsakykite su {labels_str}, ir nieko kito.",
     ),
-    LV: PromptConfig(
+    LATVIAN: PromptConfig(
         default_prompt_label_mapping=dict(correct="jā", incorrect="nē"),
         default_prompt_prefix="Šie ir teikumi un to gramatiskie pareizumi.",
         default_prompt_template="Teikums: {text}\nGramatiski pareizs: {label}",
         default_instruction_prompt="Teikums: {text}\n\nNoteiciet, vai teikums ir "
         "gramatiski pareizs vai nē. Atbildiet ar {labels_str}, un neko citu.",
     ),
-    NB: PromptConfig(
+    NORWEGIAN_BOKMÅL: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nei"),
         default_prompt_prefix="Følgende er setninger og hvorvidt de er grammatisk "
         "korrekte.",
@@ -159,7 +178,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Setning: {text}\n\nBestem om setningen er "
         "grammatisk korrekt eller ikke. Svar med {labels_str}, og ikke noe annet.",
     ),
-    NL: PromptConfig(
+    DUTCH: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nee"),
         default_prompt_prefix="Hieronder staan zinnen en of ze grammaticaal correct "
         "zijn.",
@@ -167,7 +186,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Zin: {text}\n\nBepaal of de zin grammaticaal "
         "correct is of niet. Antwoord met {labels_str}, en verder niets.",
     ),
-    NN: PromptConfig(
+    NORWEGIAN_NYNORSK: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nei"),
         default_prompt_prefix="Følgende er setninger og hvorvidt de er grammatisk "
         "korrekte.",
@@ -175,7 +194,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Setning: {text}\n\nBestem om setningen er "
         "grammatisk korrekt eller ikke. Svar med {labels_str}, og ikke noe annet.",
     ),
-    NO: PromptConfig(
+    NORWEGIAN: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nei"),
         default_prompt_prefix="Følgende er setninger og hvorvidt de er grammatisk "
         "korrekte.",
@@ -183,7 +202,7 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Setning: {text}\n\nBestem om setningen er "
         "grammatisk korrekt eller ikke. Svar med {labels_str}, og ikke noe annet.",
     ),
-    SK: PromptConfig(
+    SLOVAK: PromptConfig(
         default_prompt_label_mapping=dict(correct="áno", incorrect="nie"),
         default_prompt_prefix="Nasledujú vety a či sú gramaticky správne.",
         default_prompt_template="Veta: {text}\nGramaticky správna: {label}",
@@ -192,7 +211,16 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
             "Odpovedzte so {labels_str}, a nič iné."
         ),
     ),
-    SV: PromptConfig(
+    SERBIAN: PromptConfig(
+        default_prompt_label_mapping=dict(correct="da", incorrect="ne"),
+        default_prompt_prefix="U nastavku su rečenice i da li su gramatički ispravne.",
+        default_prompt_template="Rečenica: {text}\nGramatički ispravna: {label}",
+        default_instruction_prompt=(
+            "Rečenica: {text}\n\nOdredite da li je rečenica gramatički ispravna ili "
+            "ne. Odgovorite sa {labels_str}, i ništa drugo."
+        ),
+    ),
+    SWEDISH: PromptConfig(
         default_prompt_label_mapping=dict(correct="ja", incorrect="nej"),
         default_prompt_prefix="Följande är meningar och huruvida de är grammatiskt "
         "korrekta.",
@@ -200,4 +228,15 @@ LA_TEMPLATES: dict["Language", PromptConfig] = {
         default_instruction_prompt="Mening: {text}\n\nBestäm om meningen är "
         "grammatiskt korrekt eller inte. Svara med {labels_str}, och inget annat.",
     ),
+    UKRAINIAN: PromptConfig(
+        default_prompt_label_mapping=dict(correct="так", incorrect="ні"),
+        default_prompt_prefix=(
+            "Нижче наведені речення і їхня граматична правильність."
+        ),
+        default_prompt_template=("Речення: {text}\nГраматично правильно: {label}"),
+        default_instruction_prompt=(
+            "Речення: {text}\n\nВизначте, чи речення граматично правильне чи ні. "
+            "Відповідайте {labels_str}, і нічого більше."
+        ),
+    ),
 }
