@@ -26,9 +26,11 @@ MAX_REPETITIONS = 50
 
 
 CHOICES_MAPPING = {
+    "bg": "Възможности",
     "cs": "Výběr",
     "da": "Svarmuligheder",
     "de": "Antwortmöglichkeiten",
+    "el": "Επιλογές",
     "en": "Choices",
     "es": "Opciones",
     "et": "Vastusevariandid",
@@ -44,5 +46,7 @@ CHOICES_MAPPING = {
     "pl": "Opcje",
     "pt": "Opções",
     "sk": "Možnosti",
+    "sr": "Opcije",
     "sv": "Svarsalternativ",
+    "uk": "Варіанти",
 }
