@@ -44,6 +44,10 @@ LANGUAGES = [
     "lv",
     "lt",
     "sk",
+    "uk",
+    "el",
+    "bg",
+    "sr",
 ]
 
 
